@@ -113,7 +113,7 @@ def get_ruv(inst, basedn, log, args):
     ruv_dict = ruv.format_ruv()
     ruvs = ruv_dict['ruvs']
     if args and args.json:
-        log.info(json.dumps({"type": "list", "items": ruvs}))
+        log.info(json.dumps({"type": "list", "items": ruvs}, indent=4))
     else:
         add_gap = False
         for ruv in ruvs:
@@ -199,19 +199,21 @@ def enable_replication(inst, basedn, log, args):
 
     # Create replication manager if password was provided
     if args.bind_dn and args.bind_passwd:
-        cn_rdn = args.bind_dn.split(",", 1)[0]
-        cn_val = cn_rdn.split("=", 1)[1]
-        manager = BootstrapReplicationManager(inst, dn=args.bind_dn)
+        rdn = args.bind_dn.split(",", 1)[0]
+        rdn_attr, rdn_val = rdn.split("=", 1)
+        manager = BootstrapReplicationManager(inst, dn=args.bind_dn, rdn_attr=rdn_attr)
         try:
             manager.create(properties={
-                'cn': cn_val,
+                'cn': rdn_val,
+                'uid': rdn_val,
                 'userPassword': args.bind_passwd
             })
         except ldap.ALREADY_EXISTS:
             # Already there, but could have different password.  Delete and recreate
             manager.delete()
             manager.create(properties={
-                'cn': cn_val,
+                'cn': rdn_val,
+                'uid': rdn_val,
                 'userPassword': args.bind_passwd
             })
         except ldap.NO_SUCH_OBJECT:
@@ -275,7 +277,7 @@ def list_suffixes(inst, basedn, log, args):
         suffixes.append(replica.get_suffix())
 
     if args.json:
-        log.info(json.dumps({"type": "list", "items": suffixes}))
+        log.info(json.dumps({"type": "list", "items": suffixes}, indent=4))
     else:
         if len(suffixes) == 0:
             log.info("There are no replicated suffixes")
@@ -289,7 +291,7 @@ def get_repl_status(inst, basedn, log, args):
     replica = replicas.get(args.suffix)
     status = replica.status(binddn=args.bind_dn, bindpw=args.bind_passwd)
     if args.json:
-        log.info(json.dumps({"type": "list", "items": status}))
+        log.info(json.dumps({"type": "list", "items": status}, indent=4))
     else:
         for agmt in status:
             log.info(agmt)
@@ -300,7 +302,7 @@ def get_repl_winsync_status(inst, basedn, log, args):
     replica = replicas.get(args.suffix)
     status = replica.status(binddn=args.bind_dn, bindpw=args.bind_passwd, winsync=True)
     if args.json:
-        log.info(json.dumps({"type": "list", "items": status}))
+        log.info(json.dumps({"type": "list", "items": status}, indent=4))
     else:
         for agmt in status:
             log.info(agmt)
@@ -459,7 +461,7 @@ def get_repl_monitor_info(inst, basedn, log, args):
             report_items.append(report_item)
 
     if args.json:
-        log.info(json.dumps({"type": "list", "items": report_items}))
+        log.info(json.dumps({"type": "list", "items": report_items}, indent=4))
 
 
 def create_cl(inst, basedn, log, args):
@@ -511,22 +513,23 @@ def get_cl(inst, basedn, log, args):
 
 
 def create_repl_manager(inst, basedn, log, args):
-    manager_cn = "replication manager"
+    manager_name = "replication manager"
     repl_manager_password = ""
     repl_manager_password_confirm = ""
 
     if args.name:
-        manager_cn = args.name
+        manager_name = args.name
 
-    if is_a_dn(manager_cn):
-        # A full DN was provided, make sure it uses "cn" for the RDN
-        if manager_cn.split("=", 1)[0].lower() != "cn":
-            raise ValueError("Replication manager DN must use \"cn\" for the rdn attribute")
-        manager_dn = manager_cn
-        manager_rdn = manager_dn.split(",", 1)[0]
-        manager_cn = manager_rdn.split("=", 1)[1]
+    if is_a_dn(manager_name):
+        # A full DN was provided
+        manager_dn = manager_name
+        manager_rdn = manager_name.split(",", 1)[0]
+        manager_attr, manager_name = manager_rdn.split("=", 1)
+        if manager_attr.lower() not in ['cn', 'uid']:
+            raise ValueError(f'The RDN attribute "{manager_attr}" is not allowed, you must use "cn" or "uid"')
     else:
-        manager_dn = "cn={},cn=config".format(manager_cn)
+        manager_dn = "cn={},cn=config".format(manager_name)
+        manager_attr = "cn"
 
     if args.passwd:
         repl_manager_password = args.passwd
@@ -544,10 +547,11 @@ def create_repl_manager(inst, basedn, log, args):
                 repl_manager_password = ""
                 repl_manager_password_confirm = ""
 
-    manager = BootstrapReplicationManager(inst, dn=manager_dn)
+    manager = BootstrapReplicationManager(inst, dn=manager_dn, rdn_attr=manager_attr)
     try:
         manager.create(properties={
-            'cn': manager_cn,
+            'cn': manager_name,
+            'uid': manager_name,
             'userPassword': repl_manager_password
         })
         if args.suffix:
@@ -564,7 +568,8 @@ def create_repl_manager(inst, basedn, log, args):
         # Already there, but could have different password.  Delete and recreate
         manager.delete()
         manager.create(properties={
-            'cn': manager_cn,
+            'cn': manager_name,
+            'uid': manager_name,
             'userPassword': repl_manager_password
         })
         if args.suffix:
@@ -580,17 +585,38 @@ def create_repl_manager(inst, basedn, log, args):
 
 
 def del_repl_manager(inst, basedn, log, args):
+    """Delete the manager entry is it exists, and remove it from replica
+    configuration if a suffix was provided.
+    """
+    deleted_manager_entry = False
     if is_a_dn(args.name):
         manager_dn = args.name
     else:
         manager_dn = "cn={},cn=config".format(args.name)
     manager = BootstrapReplicationManager(inst, dn=manager_dn)
-    manager.delete()
-    if args.suffix:
-        # Add supplier DN to config
+
+    try:
+        manager.delete()
+        deleted_manager_entry = True
+    except ldap.NO_SUCH_OBJECT:
+        # This is not okay if we did not specify a suffix
+        if args.suffix is None:
+            raise ValueError(f"The replication manager entry ({manager_dn}) does not exist.")
+
+    if args.suffix is not None:
+        # Delete supplier DN from the replication config
         replicas = Replicas(inst)
         replica = replicas.get(args.suffix)
-        replica.remove('nsds5ReplicaBindDN', manager_dn)
+        try:
+            replica.remove('nsds5ReplicaBindDN', manager_dn)
+        except ldap.NO_SUCH_ATTRIBUTE:
+            # The manager was not in the config
+            msg = f"The replication manager ({manager_dn}) does not exist in the suffix replication configuration"
+            if deleted_manager_entry:
+                # We already deleted the manager entry, better say something
+                msg += ", but the replication manager entry has been deleted from the global configuration."
+            raise ValueError(msg)
+
     log.info("Successfully deleted replication manager: " + manager_dn)
 
 
@@ -612,7 +638,7 @@ def list_agmts(inst, basedn, log, args):
         else:
             log.info(agmt.display())
     if args.json:
-        log.info(json.dumps(result))
+        log.info(json.dumps(result, indent=4))
 
 
 def add_agmt(inst, basedn, log, args):
@@ -663,7 +689,7 @@ def add_agmt(inst, basedn, log, args):
         properties['nsds5replicastripattrs'] = args.strip_list
 
     # We do need the bind dn and credentials for none-sasl bind methods
-    if (bind_method == 'simple' or 'sslclientauth') and (args.bind_dn is None or args.bind_passwd is None):
+    if (bind_method in ('simple', 'sslclientauth')) and (args.bind_dn is None or args.bind_passwd is None):
         raise ValueError("You need to set the bind dn (--bind-dn) and the password (--bind-passwd) for bind method ({})".format(bind_method))
 
     # Create the agmt
@@ -712,7 +738,7 @@ def check_init_agmt(inst, basedn, log, args):
     elif error:
         status = "Agreement initialization failed: " + error
     if args.json:
-        log.info(json.dumps(status))
+        log.info(json.dumps(status, indent=4))
     else:
         log.info(status)
 
@@ -787,7 +813,7 @@ def list_winsync_agmts(inst, basedn, log, args):
         else:
             log.info(agmt.display())
     if args.json:
-        log.info(json.dumps(result))
+        log.info(json.dumps(result, indent=4))
 
 
 def add_winsync_agmt(inst, basedn, log, args):
@@ -907,7 +933,7 @@ def check_winsync_init_agmt(inst, basedn, log, args):
     elif error:
         status = "Agreement initialization failed."
     if args.json:
-        log.info(json.dumps(status))
+        log.info(json.dumps(status, indent=4))
     else:
         log.info(status)
 
@@ -933,6 +959,7 @@ def get_winsync_agmt_status(inst, basedn, log, args):
     status = agmt.status(winsync=True, use_json=args.json)
     log.info(status)
 
+
 #
 # Tasks
 #
@@ -945,7 +972,7 @@ def run_cleanallruv(inst, basedn, log, args):
     clean_task.create(properties=properties)
     rdn = clean_task.rdn
     if args.json:
-        log.info(json.dumps(rdn))
+        log.info(json.dumps(rdn, indent=4))
     else:
         log.info('Created task ' + rdn)
 
@@ -970,7 +997,7 @@ def list_cleanallruv(inst, basedn, log, args):
         else:
             log.info(task.display())
     if args.json:
-        log.info(json.dumps(result))
+        log.info(json.dumps(result, indent=4))
     else:
         if not tasks_found:
             log.info("No CleanAllRUV tasks found")
@@ -1005,7 +1032,7 @@ def list_abort_cleanallruv(inst, basedn, log, args):
         else:
             log.info(task.display())
     if args.json:
-        log.info(json.dumps(result))
+        log.info(json.dumps(result, indent=4))
     else:
         if not tasks_found:
             log.info("No CleanAllRUV abort tasks found")
@@ -1189,9 +1216,6 @@ def create_parser(subparsers):
     repl_set_parser = repl_subcommands.add_parser('set', help='Set an attribute in the replication configuration')
     repl_set_parser.set_defaults(func=set_repl_config)
     repl_set_parser.add_argument('--suffix', required=True, help='The DN of the replication suffix')
-    repl_set_parser.add_argument('--replica-id', help="The Replication Identifier number")
-    repl_set_parser.add_argument('--replica-role', help="The Replication role: master, hub, or consumer")
-
     repl_set_parser.add_argument('--repl-add-bind-dn', help="Add a bind (supplier) DN")
     repl_set_parser.add_argument('--repl-del-bind-dn', help="Remove a bind (supplier) DN")
     repl_set_parser.add_argument('--repl-add-ref', help="Add a replication referral (for consumers only)")
@@ -1329,8 +1353,7 @@ def create_parser(subparsers):
     agmt_set_parser.add_argument('--wait-async-results', help="The amount of time in milliseconds the server waits if "
                                                               "the consumer is not ready before resending data")
     agmt_set_parser.add_argument('--busy-wait-time', help="The amount of time in seconds a supplier should wait after "
-                                                          "a consumer sends back a busy response before making another "
-                                                          "attempt to acquire access.")
+                                 "a consumer sends back a busy response before making another attempt to acquire access.")
     agmt_set_parser.add_argument('--session-pause-time', help="The amount of time in seconds a supplier should wait between update sessions.")
     agmt_set_parser.add_argument('--flow-control-window', help="Sets the maximum number of entries and updates sent by a supplier, which are not acknowledged by the consumer.")
     agmt_set_parser.add_argument('--flow-control-pause', help="The time in milliseconds to pause after reaching the number of entries and updates set in \"--flow-control-window\"")
@@ -1420,8 +1443,7 @@ def create_parser(subparsers):
     winsync_agmt_add_parser.add_argument('--subtree-pair', help="Set the subtree pair: <DS_SUBTREE>:<WINDOWS_SUBTREE>")
     winsync_agmt_add_parser.add_argument('--conn-timeout', help="The timeout used for replicaton connections")
     winsync_agmt_add_parser.add_argument('--busy-wait-time', help="The amount of time in seconds a supplier should wait after "
-                                                          "a consumer sends back a busy response before making another "
-                                                          "attempt to acquire access.")
+                                         "a consumer sends back a busy response before making another attempt to acquire access.")
     winsync_agmt_add_parser.add_argument('--session-pause-time', help="The amount of time in seconds a supplier should wait between update sessions.")
     winsync_agmt_add_parser.add_argument('--init', action='store_true', default=False, help="Initialize the agreement after creating it.")
 
@@ -1450,8 +1472,7 @@ def create_parser(subparsers):
     winsync_agmt_set_parser.add_argument('--subtree-pair', help="Set the subtree pair: <DS_SUBTREE>:<WINDOWS_SUBTREE>")
     winsync_agmt_set_parser.add_argument('--conn-timeout', help="The timeout used for replicaton connections")
     winsync_agmt_set_parser.add_argument('--busy-wait-time', help="The amount of time in seconds a supplier should wait after "
-                                                          "a consumer sends back a busy response before making another "
-                                                          "attempt to acquire access.")
+                                         "a consumer sends back a busy response before making another attempt to acquire access.")
     winsync_agmt_set_parser.add_argument('--session-pause-time', help="The amount of time in seconds a supplier should wait between update sessions.")
 
     # Get
