@@ -1,5 +1,5 @@
 # --- BEGIN COPYRIGHT BLOCK ---
-# Copyright (C) 2019 Red Hat, Inc.
+# Copyright (C) 2020 Red Hat, Inc.
 # Copyright (C) 2019 William Brown <william@blackhats.net.au>
 # All rights reserved.
 #
@@ -8,7 +8,6 @@
 # --- END COPYRIGHT BLOCK ---
 
 import os
-import logging
 import sys
 import shutil
 import pwd
@@ -24,7 +23,13 @@ from lib389.properties import *
 from lib389.passwd import password_hash, password_generate
 from lib389.nss_ssl import NssSsl
 from lib389.configurations import get_config
-from lib389.configurations.sample import create_base_domain
+from lib389.configurations.sample import (
+    create_base_domain,
+    create_base_org,
+    create_base_orgunit,
+    create_base_cn,
+    create_base_c,
+)
 from lib389.instance.options import General2Base, Slapd2Base, Backend2Base
 from lib389.paths import Paths
 from lib389.saslmap import SaslMappings
@@ -219,7 +224,7 @@ class SetupDs(object):
         insts = inst.list(serverid=serverid)
 
         if len(insts) != 1:
-            log.error("No such instance to remove {}".format(serverid))
+            self.log.error("No such instance to remove {}".format(serverid))
             return
         inst.allocate(insts[0])
         remove_ds_instance(inst, force=True)
@@ -276,6 +281,7 @@ class SetupDs(object):
                  'inst_dir': ds_paths.inst_dir,
                  'backup_dir': ds_paths.backup_dir,
                  'db_dir': ds_paths.db_dir,
+                 'db_home_dir': ds_paths.db_home_dir,
                  'ldif_dir': ds_paths.ldif_dir,
                  'lock_dir': ds_paths.lock_dir,
                  'log_dir': ds_paths.log_dir,
@@ -561,6 +567,15 @@ class SetupDs(object):
 
         # We need to know the prefix before we can do the instance checks
         assert_c(slapd['instance_name'] is not None, "Configuration instance_name in section [slapd] not found")
+        assert_c(len(slapd['instance_name']) <= 80, "Server identifier should not be longer than 80 symbols")
+        assert_c(all(ord(c) < 128 for c in slapd['instance_name']), "Server identifier can not contain non ascii characters")
+        assert_c(' ' not in slapd['instance_name'], "Server identifier can not contain a space")
+        assert_c(slapd['instance_name'] != 'admin', "Server identifier \"admin\" is reserved, please choose a different identifier")
+
+        # Check that valid characters are used
+        safe = re.compile(r'^[#%:\w@_-]+$').search
+        assert_c(bool(safe(slapd['instance_name'])), "Server identifier has invalid characters, please choose a different value")
+
         # Check if the instance exists or not.
         # Should I move this import? I think this prevents some recursion
         from lib389 import DirSrv
@@ -714,7 +729,7 @@ class SetupDs(object):
                 dse += line.replace('%', '{', 1).replace('%', '}', 1)
 
         with open(os.path.join(slapd['config_dir'], 'dse.ldif'), 'w') as file_dse:
-            file_dse.write(dse.format(
+            dse_fmt = dse.format(
                 schema_dir=slapd['schema_dir'],
                 lock_dir=slapd['lock_dir'],
                 tmp_dir=slapd['tmp_dir'],
@@ -728,13 +743,16 @@ class SetupDs(object):
                 ds_port=slapd['port'],
                 ds_user=slapd['user'],
                 rootdn=slapd['root_dn'],
+                instance_name=slapd['instance_name'],
                 ds_passwd=self._secure_password,  # We set our own password here, so we can connect and mod.
                 # This is because we never know the users input root password as they can validily give
                 # us a *hashed* input.
                 ds_suffix=ds_suffix,
                 config_dir=slapd['config_dir'],
                 db_dir=slapd['db_dir'],
-            ))
+                db_home_dir=slapd['db_home_dir']
+            )
+            file_dse.write(dse_fmt)
 
         # Create all the needed paths
         # we should only need to make bak_dir, cert_dir, config_dir, db_dir, ldif_dir, lock_dir, log_dir, run_dir?
@@ -805,14 +823,15 @@ class SetupDs(object):
         # Create certdb in sysconfidir
         self.log.debug("ACTION: Creating certificate database is %s", slapd['cert_dir'])
 
-        # BELOWE THIS LINE - all actions are now ONLINE changes to the directory server.
+        # BELOW THIS LINE - all actions are now ONLINE changes to the directory server.
         # if it all possible, ALWAYS ADD NEW INSTALLER CHANGES AS ONLINE ACTIONS.
 
         # Should I move this import? I think this prevents some recursion
         from lib389 import DirSrv
         ds_instance = DirSrv(self.verbose)
         if self.containerised:
-            ds_instance.systemd = general['systemd']
+            ds_instance.systemd_override = general['systemd']
+
         args = {
             SER_PORT: slapd['port'],
             SER_SERVERID_PROP: slapd['instance_name'],
@@ -857,8 +876,9 @@ class SetupDs(object):
 
         # Do selinux fixups
         if general['selinux']:
-            selinux_paths = ('backup_dir', 'cert_dir', 'config_dir', 'db_dir', 'ldif_dir',
-                             'lock_dir', 'log_dir', 'run_dir', 'schema_dir', 'tmp_dir')
+            selinux_paths = ('backup_dir', 'cert_dir', 'config_dir', 'db_dir',
+                             'ldif_dir', 'lock_dir', 'log_dir',
+                             'run_dir', 'schema_dir', 'tmp_dir')
             for path in selinux_paths:
                 selinux_restorecon(slapd[path])
 
@@ -895,14 +915,31 @@ class SetupDs(object):
             create_suffix_entry_in_props = backend.pop('create_suffix_entry', False)
             ds_instance.backends.create(properties=backend)
             if not is_sample_entries_in_props and create_suffix_entry_in_props:
-                domain = create_base_domain(ds_instance, backend['nsslapd-suffix'])
-                # Set basic ACI
-                domain.add('aci', [
-                    # Allow reading the base domain object
-                    '(targetattr="dc || description || objectClass")(targetfilter="(objectClass=domain)")(version 3.0; acl "Enable anyone domain read"; allow (read, search, compare)(userdn="ldap:///anyone");)',
-                    # Allow reading the ou
-                    '(targetattr="ou || objectClass")(targetfilter="(objectClass=organizationalUnit)")(version 3.0; acl "Enable anyone ou read"; allow (read, search, compare)(userdn="ldap:///anyone");)'
-                ])
+                # Set basic ACIs
+                c_aci = '(targetattr="c || description || objectClass")(targetfilter="(objectClass=country)")(version 3.0; acl "Enable anyone c read"; allow (read, search, compare)(userdn="ldap:///anyone");)'
+                o_aci = '(targetattr="o || description || objectClass")(targetfilter="(objectClass=organization)")(version 3.0; acl "Enable anyone o read"; allow (read, search, compare)(userdn="ldap:///anyone");)'
+                dc_aci = '(targetattr="dc || description || objectClass")(targetfilter="(objectClass=domain)")(version 3.0; acl "Enable anyone domain read"; allow (read, search, compare)(userdn="ldap:///anyone");)'
+                ou_aci = '(targetattr="ou || description || objectClass")(targetfilter="(objectClass=organizationalUnit)")(version 3.0; acl "Enable anyone ou read"; allow (read, search, compare)(userdn="ldap:///anyone");)'
+                cn_aci = '(targetattr="cn || description || objectClass")(targetfilter="(objectClass=nscontainer)")(version 3.0; acl "Enable anyone cn read"; allow (read, search, compare)(userdn="ldap:///anyone");)'
+                suffix_rdn_attr = backend['nsslapd-suffix'].split('=')[0].lower()
+                if suffix_rdn_attr == 'dc':
+                    domain = create_base_domain(ds_instance, backend['nsslapd-suffix'])
+                    domain.add('aci', dc_aci)
+                elif suffix_rdn_attr == 'o':
+                    org = create_base_org(ds_instance, backend['nsslapd-suffix'])
+                    org.add('aci', o_aci)
+                elif suffix_rdn_attr == 'ou':
+                    orgunit = create_base_orgunit(ds_instance, backend['nsslapd-suffix'])
+                    orgunit.add('aci', ou_aci)
+                elif suffix_rdn_attr == 'cn':
+                    cn = create_base_cn(ds_instance, backend['nsslapd-suffix'])
+                    cn.add('aci', cn_aci)
+                elif suffix_rdn_attr == 'c':
+                    c = create_base_c(ds_instance, backend['nsslapd-suffix'])
+                    c.add('aci', c_aci)
+                else:
+                    # Unsupported rdn
+                    raise ValueError("Suffix RDN '{}' in '{}' is not supported.  Supported RDN's are: 'c', 'cn', 'dc', 'o', and 'ou'".format(suffix_rdn_attr, backend['nsslapd-suffix']))
 
         # Initialise ldapi socket information. IPA expects this ....
         ldapi_path = os.path.join(slapd['local_state_dir'], "run/slapd-%s.socket" % slapd['instance_name'])
